import React,{Component} from "react";
import Taro from '@tarojs/taro';
import {View,Image} from '@tarojs/components';
import {AtSlider} from 'taro-ui'
import './index.less';
import audioPlay from '../../assets/images/audioPlay.png';
import autioSuspend from '../../assets/images/autioSuspend.png';

class Audio extends Component{
  innerAudioContext = Taro.createInnerAudioContext()

  constructor(props) {
    super(props);
    this.state={
      audioPlay: false,
      audioPercent: 0,
      nowTime:'0:00',
      durationTime: '0:00',
    }
  }

  componentDidMount() {
    this.innerAudioContext.src = this.props.audioFile;
    this.innerAudioContext.autoplay = true;
    this.innerAudioContext.onPlay(() => {
      this.setState({
        audioPlay: true
      })
    })
    this.innerAudioContext.onPause(() => {
      this.setState({
        audioPlay: false
      })
    })
    //播放结束
    this.innerAudioContext.onEnded(() => {
      this.innerAudioContext.stop();
      this.setState({
        audioPlay: false,
        audioPercent: this.innerAudioContext.duration,
        nowTime:this.format(Math.round(this.innerAudioContext.duration)),
      },()=>{
        setTimeout(()=>{
          this.setState({
            audioPercent: 0,
            nowTime:this.format(0),
          })
        },200)
      })
    })
    this.innerAudioContext.onError((res) => {
      console.log(res.errMsg)
      console.log(res.errCode)
      Taro.showToast({title:'语音文件错误,请下拉页面刷新后重试',icon:'none'});

    })
    this.innerAudioContext.onTimeUpdate(() => {
      this.setState({
        audioPercent: this.innerAudioContext.currentTime,
        duration: this.innerAudioContext.duration,
        nowTime:this.format(Math.round(this.innerAudioContext.currentTime)),
        durationTime: this.format(Math.round(this.innerAudioContext.duration)),
      })
    })
  }

  componentWillUnmount(){
    this.innerAudioContext.destroy();
  }

  format(value) {
    let theTime = parseInt(value);// 秒
    let middle= 0;// 分
    let hour= 0;// 小时
    if(theTime > 60) {
      middle= parseInt(theTime/60);
      theTime = parseInt(theTime%60);
      if(middle> 60) {
        hour= parseInt(middle/60);
        middle= parseInt(middle%60);
      }
    }
    let result = ''
    if(parseInt(theTime)>=10){
      result = "0"+":"+parseInt(theTime);
    }else{
      result= "0"+":"+"0"+parseInt(theTime);
    }
    if(middle >= 0 && parseInt(theTime)>=10) {
      result = parseInt(middle)+":"+parseInt(theTime);
    }else{
      result = parseInt(middle)+":"+"0"+parseInt(theTime);
    }
    return result;
  }


  render() {
    return (
      <View className='audioComponents'>
        {this.state.audioPlay ?
          <Image
            src={autioSuspend}
            className='suspend'
            onClick={()=>{
              this.innerAudioContext.pause()
            }}/> :
          <Image
            src={audioPlay}
            className='play'
            onClick={()=>{
              this.innerAudioContext.play()
            }}
          />}
        <View className='atProgress'>
          <AtSlider
            min={0}
            step={0.1}
            max={this.state.duration}
            value={this.state.audioPercent}
            onChange={(value)=>{
              this.setState({
                audioPercent: parseFloat(value.toFixed(2)),
                nowTime:this.format(Math.round(value)),
              })
              this.innerAudioContext.seek(parseFloat(value.toFixed(2)));
            }}
            onChanging={(value)=>{
              this.innerAudioContext.pause();
              this.setState({
                audioPercent: parseFloat(value.toFixed(2)),
                nowTime:this.format(Math.round(value)),
              })
            }}
          />
          {
            this.state.nowTime+'/'+ this.state.durationTime
          }
        </View>
      </View>

    )
  }
}

export default Audio
