import { Component } from 'react';
import Taro from '@tarojs/taro';
import { connect } from 'react-redux'
import { View, Image } from '@tarojs/components'
import { set } from '../../actions/counter'
import { getLiveList } from '../../utils/servers/servers'
import dayjs from 'dayjs';

import ListBottomStart from '../../components/common/listBottomStart';

import './index.less';

import background from '../../assets/images/background.png';
import NavBar from "../../components/NavBar";

@connect(({ counter }) => ({
  counter
}), (dispatch) => ({
  set(value) {
    dispatch(set(value))
  }
}))
class LiveList extends Component {

  constructor(props) {
    super(props);
    this.state = {
      list: [],
      pageNo: 0,
      listState: 'LOADING',
    }
    this.getLiveList = this.getLiveList.bind(this);
  }

  async componentDidShow() {
    this.props.set(1);
  }

  async componentDidMount() {
    await this.getLiveList();
  }

  onPullDownRefresh() {
    this.getLiveList();
  }

  onReachBottom() {
    this.getLiveList(this.state.pageNo + 1);
  }

  async getLiveList(pageNo = 1) {
    this.setState({
      listState: 'LOADING'
    })
    let msg = await getLiveList({
      pageNo: pageNo,
      pageSize: 10,
    });
    if (msg.error.length === 0) {
      if (msg.data.totalCount === 0) {
        this.setState({
          listState: 'NO_DATA'
        })
      } else if (msg.data.totalCount === this.state.list.length && pageNo !== 1) {
        Taro.showToast({ title: '没有更多数据了', icon: 'none' });
        this.setState({
          listState: 'NO_MORE_DATA'
        })
      } else {
        this.setState({
          list: pageNo === 1 ? msg.data.list : this.state.list.concat(msg.data.list),
          pageNo: msg.data.pageNo
        }, () => {
          if (msg.data.totalCount === this.state.list.length) {
            this.setState({
              listState: 'NO_MORE_DATA'
            })
          }
        })
      }
    } else {
      Taro.showToast({ title: msg.error[0].message, icon: 'none' });
      this.setState({
        listState: msg.error[0].field === '403' ? 'NO_DATA' : 'RELOAD'
      })
    }
    Taro.stopPullDownRefresh();
  }

  render() {
    return (
      <View className='livePlayerPage'>
        <NavBar
          extClass='NavBar'
          title='直播'
          background='#7ac7ff'
          onHome={() => { }}
        />
        <Image src={background} className='background' />
        <View className='title'>推荐</View>
        <View className='list'>
          {
            this.state.list.map((v, k) => (
              <View key={k} className='item' onClick={() => {
                let customParams = encodeURIComponent(JSON.stringify({ path: 'pages/liveRoom/index', pid: 1 }));
                let url = 'plugin-private://wx2b03c6e691cd7370/pages/live-player-plugin?room_id=' + v.roomid + '&custom_params=' + customParams;
                Taro.navigateTo({
                  url
                })
              }}>
                <View className='infor'>
                  <View className='name'>{v.name}</View>
                  <View className='createTimes'>{
                    v.live_status === 101 ? '直播中' :
                      v.live_status === 102 ? '未开始' :
                        v.live_status === 103 ? '已结束' :
                          v.live_status === 104 ? '禁播' :
                            v.live_status === 105 ? '暂停' :
                              v.live_status === 106 ? '异常' :
                                v.live_status === 107 ? '已过期' : ''
                  }</View>
                  <View className='amount'>
                    {/*<View className='money'>开播时间:</View>*/}
                    {dayjs.unix(v.start_time).format('YYYY-MM-DD HH:mm:ss')}
                  </View>
                </View>
                <Image className='thumbnailUrl' src={v.feeds_img} resizeMode='center' />
              </View>
            ))
          }
          <ListBottomStart
            state={this.state.listState}
            reload={() => {
              this.getLiveList(this.state.pageNo + 1);
            }} />
        </View>
      </View>
    )
  }
}

export default LiveList
