import { Component } from 'react';
import Taro from '@tarojs/taro';
import {View, Image, Video} from '@tarojs/components'
import AudioPlayer from '../../components/audio';

import { payClose,getSelectProject,wxQuery } from '../../utils/servers/servers';
import {resourceAddress} from '../../utils/config';

import './index.less'

import background from '../../assets/images/background.png';

class Details extends Component {

  constructor(props) {
    super(props);
    this.state={
      projectInfor: {},
    }
    this.payClose= this.payClose.bind(this);
    this.wxQuery= this.wxQuery.bind(this);
  }

  componentDidMount() {
    this.getSelectProject();
  }

  onPullDownRefresh(){
    this.getSelectProject();
  }

  //H5跳转到微信小程序
  jumpWeapp(){
    window.location.href='https://cloud1-2gpyny9bdfc8c33a-1305545304.tcloudbaseapp.com/jump-mp.html?sign=639f843ec9b22075c5ce44e301060206&t=1618818701&id=27';
  }

  payClose(orderNo){
    payClose({
      orderNo,
    }).then(v => {
      if(v.error.length === 0){
        Taro.showToast({title:'已取消支付',icon:'none'});
      }else{
        Taro.showToast({title:v.error[0].message,icon:'none'})
      }
    }).catch(err => {
      Taro.showToast({title:'系统错误,请稍后重试',icon:'none'});
      console.log(err)
    })
  }

  wxQuery(orderNo){
    wxQuery({
      orderNo:orderNo,
    }).then(v => {
      if(v.error.length === 0){
        this.getSelectProject();
      }else{
        Taro.showToast({title:v.error[0].message,icon:'none'})
      }
    }).catch(err => {
      Taro.showToast({title:'系统错误,请稍后重试',icon:'none'});
      console.log(err)
    })
  }

  getSelectProject(){
    getSelectProject({
      id:27,
    }).then(v => {
      if(v.error.length === 0){
        this.setState({
          projectInfor: v.data
        })
      }else{
        Taro.showToast({title:v.error[0].message,icon:'none'})
      }
    }).catch(err => {
      Taro.showToast({title:'系统错误,请稍后重试',icon:'none'});
      console.log(err)
    })
    Taro.stopPullDownRefresh();
  }


  render () {
    const { projectInfor } = this.state;
    return (
      <View className='detailsPage'>
        <Image src={background} className='background'/>
        <View className='introduce'>
          <View className='imgContent'>
            {
              projectInfor.buy === 0 ?
                <Image onClick={()=>{
                  Taro.previewMedia({
                    sources: [
                      {
                        url: resourceAddress + projectInfor.thumbnailUrl + ''
                      }
                    ]
                  });
                }} objectFit='contain' src={resourceAddress + projectInfor.thumbnailUrl} className='img'/> :
                projectInfor.commodityType === 1 ?
                  <Video
                    src={resourceAddress + projectInfor.commodityUrl}
                    controls
                    autoplay={false}
                    poster={resourceAddress + projectInfor.thumbnailUrl}
                    initialTime='0'
                    direction={-90}
                    enableAutoRotation
                    showBackgroundPlaybackButton
                    id='video'
                    loop={false}
                    muted={false}
                  /> : projectInfor.commodityType === 2 ?
                  <View className='audio'>
                    <Image objectFit='contain' src={resourceAddress + projectInfor.thumbnailUrl} className='audioImg'/>
                    <View className='operation'>
                      <AudioPlayer audioFile={resourceAddress + projectInfor.commodityUrl}/>
                    </View>
                  </View> : <Image objectFit='contain' src={resourceAddress + projectInfor.commodityUrl} className='img'/>
            }
          </View>
          <View className='infor'>
            <View className='title'>{projectInfor.name}</View>
            <View className='introduceItem'>
              <View className='introduceContent'>
                {
                  projectInfor.summary
                }
              </View>
              <View className='user'>
                <View className='typeName'>
                  {projectInfor.typeName}
                </View>
              </View>
            </View>
          </View>
        </View>
        <View className='detailsContent'>
          <View className='details'>产品详情</View>
          <mp-html content={projectInfor.buy === 0 ? projectInfor.content : projectInfor.commodityContent} />
        </View>
        <View className='shop'>
          <View className='singlePurchase' onClick={()=>{
            this.jumpWeapp();
          }}>购买: ¥{projectInfor.amount}</View>
        </View>
      </View>
    )
  }
}

export default Details

